@@ -66,8 +66,6 @@ class FiefUserInfo(dict):
     """
     Dictionary containing user information.
 
-    [User fields](https://docs.fief.dev/getting-started/user-fields/) values for this user are also present, indexed by their slug.
-
     **Example:**
 
     ```json
@@ -75,8 +73,10 @@ class FiefUserInfo(dict):
         "sub": "aeeb8bfa-e8f4-4724-9427-c3d5af66190e",
         "email": "anne@bretagne.duchy",
         "tenant_id": "c91ecb7f-359c-4244-8385-51ecd6c0d06b",
-        "first_name": "Anne",
-        "last_name": "De Bretagne",
+        "fields": {
+            "first_name": "Anne",
+            "last_name": "De Bretagne"
+        }
     }
     ```
     """
@@ -93,6 +93,10 @@ class FiefUserInfo(dict):
     """
     ID of the [tenant](https://docs.fief.dev/getting-started/tenants/) associated to the user.
     """
+    fields: Dict[str, Any]
+    """
+    [User fields](https://docs.fief.dev/getting-started/user-fields/) values for this user, indexed by their slug.
+    """
 
 
 class FiefError(Exception):
@@ -595,7 +599,7 @@ class Fief(BaseFief):
 
         **You're still responsible for clearing your own session mechanism if any.**
 
-        :param redirect_uri: A valid URL where the user will be redirected after the logout process:
+        :param redirect_uri: A valid URL where the user will be redirected after the logout process.
 
         **Example:**
 
